@@ -1,7 +1,7 @@
 package Test::SQL::Schema::Versioned;
 
-our $DATE = '2015-04-22'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $DATE = '2015-04-24'; # DATE
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use strict;
@@ -13,6 +13,7 @@ our @EXPORT = qw(
                     sql_schema_spec_ok
             );
 
+use DBIx::Diff::Schema qw(diff_db_schema);
 use SQL::Schema::Versioned qw(create_or_update_db_schema);
 use Test::Exception;
 use Test::More;
@@ -29,28 +30,34 @@ sub sql_schema_spec_ok {
             ok($spec->{install_v1}, 'has install_v1') or return;
         }
 
+        my $dbh1;
         subtest "testing schema creation using install" => sub {
-            my $dbh = $twdb->create_db;
+            $dbh1 = $twdb->create_db;
             lives_ok {
-                my $res = create_or_update_db_schema(dbh=>$dbh, spec=>$spec);
+                my $res = create_or_update_db_schema(dbh=>$dbh1, spec=>$spec);
                 is($res->[0], 200, 'create/update status') or diag explain $res;
             };
         };
 
+        my $dbh2;
         subtest "testing schema upgrade from v1" => sub {
-            my $dbh = $twdb->create_db;
+            $dbh2 = $twdb->create_db;
             lives_ok {
                 local $spec->{install} = $spec->{install_v1};
                 local $spec->{latest_v} = 1;
-                my $res = create_or_update_db_schema(dbh=>$dbh, spec=>$spec);
+                my $res = create_or_update_db_schema(dbh=>$dbh2, spec=>$spec);
                 is($res->[0], 200, 'create/update status') or diag explain $res;
             } "create with install_v1";
 
             lives_ok {
-                my $res = create_or_update_db_schema(dbh=>$dbh, spec=>$spec);
+                my $res = create_or_update_db_schema(dbh=>$dbh2, spec=>$spec);
                 is($res->[0], 200, 'create/update status') or diag explain $res;
             };
         } if $spec->{latest_v} > 1;
+
+        my $diff = diff_db_schema($dbh1, $dbh2);
+        is_deeply($diff, {}, 'create from scratch vs upgrade from v1 results in the same database schema')
+            or diag explain $diff;
     };
 }
 
@@ -69,13 +76,14 @@ Test::SQL::Schema::Versioned - Test SQL::Schema::Versioned spec
 
 =head1 VERSION
 
-This document describes version 0.16 of Test::SQL::Schema::Versioned (from Perl distribution SQL-Schema-Versioned), released on 2015-04-22.
+This document describes version 0.17 of Test::SQL::Schema::Versioned (from Perl distribution SQL-Schema-Versioned), released on 2015-04-24.
 
 =head1 FUNCTIONS
 
-=head2 sql_schema_spec_ok($spec[ , $twdb ])
+=head2 sql_schema_spec_ok($spec, $twdb)
 
-Test C<$spec>. C<$twdb> is an instance of L<Test::WithDB>.
+Test C<$spec>. C<$twdb> is an instance of L<Test::WithDB> (e.g. Test::WithDB
+itself or L<Test::WithDB::SQLite>).
 
 =head1 HOMEPAGE
 
@@ -83,7 +91,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/SQL-Schema
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-SHARYANTO-SQL-Schema>.
+Source repository is at L<https://github.com/perlancar/perl-SQL-Schema-Versioned>.
 
 =head1 BUGS
 
